package cn.estsh.i3plus.pojo.base.enumutil;

import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * @Description :
 * @Reference :
 * @Author : Castle
 * @CreateDate : 2022/1/18 16:10
 * @Modify:
 **/
public class BspEnumUtil {


    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum PARAM_TYPE {
        METHOD_PARAM_TYPE(10, "method", "方法参数"),
        SCRIPT_PARAM_TYPE(20, "script", "脚本参数");
        private Integer value;
        private String code;
        private String description;

        PARAM_TYPE(Integer value, String code, String description) {
            this.value = value;
            this.code = code;
            this.description = description;
        }

        public static PARAM_TYPE getByValue(String value) {
            for (PARAM_TYPE actionType : values()) {
                if (actionType.getValue().equals(value)) {
                    return actionType;
                }
            }
            return null;
        }

        public Integer getValue() {
            return value;
        }

        public String getCode() {
            return code;
        }

        public String getDescription() {
            return description;
        }
    }


    /**
     * 语言类型（Groovy、Python、JavaScript、Scala、Ruby）
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum SCRIPT_LANGUAGE {
        GROOVY(10, "Groovy"),
        PYTHON(20, "Python"),
        JAVA_SCRIPT(30, "JavaScript"),
        SCALA(40, "Scala"),
        RUBY(50, "Ruby");

        private int value;
        private String description;

        SCRIPT_LANGUAGE(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }

    /**
     * 脚本类型（Groovy、Python、JavaScript、Scala、Ruby）
     * 用于策略模式，脚本执行
     * 要和language_type一对一
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum SCRIPT_TYPE {
        GROOVY(10, "groovyScript"),
        PYTHON(20, "pythonScript"),
        JAVA_SCRIPT(30, "javaScript"),
        SCALA(40, "scalaScript"),
        RUBY(50, "rubyScript");

        private int value;
        private String beanName;

        SCRIPT_TYPE(int value, String beanName) {
            this.value = value;
            this.beanName = beanName;
        }

        public int getValue() {
            return value;
        }

        public String getBeanName() {
            return beanName;
        }

        public static String valueOfBeanName(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].beanName;
                }
            }
            return tmp;
        }
    }

    /**
     * 方法组类型
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum METHOD_GROUP_TYPE {
        BSP(10, "BSP"),
        WMS(20, "WMS"),
        MES(30, "MES"),
        APS(40, "APS"),
        MES_PCN(50, "MES_PCN");

        private int value;
        private String description;

        METHOD_GROUP_TYPE(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }


    /**
     * 执行器区分执行的是方法还是脚本
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum METHOD_OR_SCRIPT {
        METHOD(10, "METHOD"),
        SCRIPT(20, "SCRIPT");

        private int value;
        private String description;

        METHOD_OR_SCRIPT(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }
}
